% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/SuessR_Reference_Data.R
\docType{data}
\name{SuessR.reference.data}
\alias{SuessR.reference.data}
\title{Reference dataset for the SuessR Package}
\format{
A data frame with 696 rows and 8 variables:
\describe{
    \item{year}{calendar year, 1850-2024}
    \item{region}{geographic region, 'Aleutian Islands', 'Bering Sea', 'Gulf of Alaska', or 'Subpolar North Atlantic'}
    \item{r}{average cell radius of phytoplankton community, in microns}
    \item{sst}{yearly average sea surface temperature, in degrees C}
    \item{sss}{yearly average sea surface salinity, in practical salinity units}
    \item{CO2atm}{yearly average global atmospheric CO2 concentrations, in parts per million}
    \item{up.con}{regional uptake constant for Suess correction, unitless}
    \item{Cp}{Proportional change constant of oceanic/atmospheric CO\ifelse{html}{\out{<sub>2</sub>}}{\eqn{_2}} (regional), a proportion}
    }
}
\source{
\url{https://psl.noaa.gov/data/gridded/data.noaa.ersst.v5.html}\cr

\url{https://catalog.data.gov/dataset/soda-pop-2-2-4-monthly-means-1871-2010-at-depths}\cr

\url{https://coastwatch.noaa.gov/cw/satellite-data-products/sea-surface-salinity/miras-smos.html}\cr

\url{https://scrippsco2.ucsd.edu/data/atmospheric_co2/icecore_merged_products.html}\cr
}
\usage{
SuessR.reference.data
}
\description{
A dataset containing the information used by SuessR to calculate regional Suess and Laws corrections
for \ifelse{html}{\out{&delta;<sup>13</sup>}}{\eqn{{\delta}^{13}}}C from marine organisms.
}
\references{
Clark, C.T., M.R. Cape, M.D. Shapley, F.J. Mueter, B.P. Finney, and N. Misarti. (2021) SuessR: Regional Suess
  and Laws corrections for \ifelse{html}{\out{&delta;<sup>13</sup>}}{\eqn{{\delta}^{13}}}C from marine organisms. Methods
   in Ecology and Evolution. 12(8), 1508-1520.\cr

Huang, B., Thorne, P. W., Banzon, V. F., Boyer, T., Chepurin, G., Lawrimore, J. H., … Zhang, H.-M. (2017).
  NOAA extended reconstructed sea surface temperature (ERSST), version 5. doi:10.7289/V5T72FNM.\cr

Giese, B. S., & Ray, S. (2011). El Niño variability in simple ocean data assimilation (SODA), 1871-2008.
  Journal of Geophysical Research: Oceans, 116(2), 1–17. doi:10.1029/2010JC006695.\cr

Keeling, C. D., Piper, S. C., Bacastow, R. B., Wahlen, M., Whorf, T. P., Heimann, M., & Meijer, H. A. (2005).
  Atmospheric CO2 and 13CO2 exchange with the terrestrial biosphere and oceans from 1978 to 2000: Observations
  and carbon cycle implications. In A history of atmospheric CO2 and its effects on plants, animals, and
  ecosystems (pp. 83–113). Springer.\cr

MacFarling Meure, C., Etheridge, D., Trudinger, C., Steele, P., Langenfelds, R., Van Ommen, T., … Elkins, J. (2006).
  Law Dome CO2, CH4 and N2O ice core records extended to 2000 years BP. Geophysical Research Letters, 33(14),
  2000–2003. doi:10.1029/2006GL026152.\cr
}
\keyword{datasets}
